"use strict";
/********************************************************************************
 * Copyright (C) 2017 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var uri_1 = require("@devpodio/core/lib/common/uri");
var browser_1 = require("@devpodio/languages/lib/browser");
var common_1 = require("../common");
var typescript_preferences_1 = require("./typescript-preferences");
var TypeScriptClientContribution = /** @class */ (function (_super) {
    __extends(TypeScriptClientContribution, _super);
    function TypeScriptClientContribution(workspace, languages, languageClientFactory) {
        var _this = _super.call(this, workspace, languages, languageClientFactory) || this;
        _this.workspace = workspace;
        _this.languages = languages;
        _this.languageClientFactory = languageClientFactory;
        _this.id = common_1.TYPESCRIPT_LANGUAGE_ID;
        _this.name = common_1.TYPESCRIPT_LANGUAGE_NAME;
        return _this;
    }
    TypeScriptClientContribution.prototype.init = function () {
        var _this = this;
        this.preferences.onPreferenceChanged(function (e) {
            if (e.preferenceName === 'typescript.server.log') {
                _this.restart();
            }
        });
    };
    Object.defineProperty(TypeScriptClientContribution.prototype, "documentSelector", {
        get: function () {
            return [
                common_1.TYPESCRIPT_LANGUAGE_ID,
                common_1.TYPESCRIPT_REACT_LANGUAGE_ID,
                common_1.JAVASCRIPT_LANGUAGE_ID,
                common_1.JAVASCRIPT_REACT_LANGUAGE_ID
            ];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TypeScriptClientContribution.prototype, "workspaceContains", {
        get: function () {
            // FIXME requires https://github.com/theia-ide/theia/issues/2359
            // return [
            //     "**/tsconfig.json",
            //     "**/jsconfig.json",
            //     "**/tsconfig.*.json",
            //     "**/jsconfig.*.json"
            // ];
            return [
                'tsconfig.json',
                'jsconfig.json'
            ];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TypeScriptClientContribution.prototype, "initializationOptions", {
        get: function () {
            var options = {};
            var logVerbosity = this.preferences['typescript.server.log'];
            if (logVerbosity !== 'off') {
                options.logVerbosity = logVerbosity;
            }
            return options;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TypeScriptClientContribution.prototype, "logFileUri", {
        get: function () {
            return this._logFileUri;
        },
        enumerable: true,
        configurable: true
    });
    TypeScriptClientContribution.prototype.onReady = function (languageClient) {
        var _this = this;
        if (languageClient.initializeResult) {
            var initializeResult = languageClient.initializeResult;
            this._logFileUri = initializeResult.logFileUri !== undefined ? new uri_1.default(initializeResult.logFileUri) : undefined;
        }
        languageClient.onDidChangeState(function (_a) {
            var newState = _a.newState;
            if (newState === browser_1.State.Stopped) {
                _this._logFileUri = undefined;
            }
        });
        _super.prototype.onReady.call(this, languageClient);
    };
    __decorate([
        inversify_1.inject(typescript_preferences_1.TypescriptPreferences),
        __metadata("design:type", Object)
    ], TypeScriptClientContribution.prototype, "preferences", void 0);
    __decorate([
        inversify_1.postConstruct(),
        __metadata("design:type", Function),
        __metadata("design:paramtypes", []),
        __metadata("design:returntype", void 0)
    ], TypeScriptClientContribution.prototype, "init", null);
    TypeScriptClientContribution = __decorate([
        inversify_1.injectable(),
        __param(0, inversify_1.inject(browser_1.Workspace)),
        __param(1, inversify_1.inject(browser_1.Languages)),
        __param(2, inversify_1.inject(browser_1.LanguageClientFactory)),
        __metadata("design:paramtypes", [Object, Object, browser_1.LanguageClientFactory])
    ], TypeScriptClientContribution);
    return TypeScriptClientContribution;
}(browser_1.BaseLanguageClientContribution));
exports.TypeScriptClientContribution = TypeScriptClientContribution;
//# sourceMappingURL=typescript-client-contribution.js.map